aboutsummaryrefslogtreecommitdiff
path: root/gcc/cfgexpand.c
diff options
context:
space:
mode:
Diffstat (limited to 'gcc/cfgexpand.c')
-rw-r--r--gcc/cfgexpand.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/gcc/cfgexpand.c b/gcc/cfgexpand.c
index 220b6ad..d2c8655 100644
--- a/gcc/cfgexpand.c
+++ b/gcc/cfgexpand.c
@@ -808,8 +808,8 @@ stack_protect_classify_type (tree type)
return ret;
}
-/* Return non-zero if DECL should be segregated into the "vulnerable" upper
- part of the local stack frame. Remember if we ever return non-zero for
+/* Return nonzero if DECL should be segregated into the "vulnerable" upper
+ part of the local stack frame. Remember if we ever return nonzero for
any variable in this function. The return value is the phase number in
which the variable should be allocated. */